@@ -1,13 +1,12 @@
 package Acme::Resume;
 
-our $VERSION = '0.0101'; # VERSION
-# ABSTRACT: Write a humuan-readable résumé in Perl
+our $VERSION = '0.0102'; # VERSION
+# ABSTRACT: Write a human-readable resume in Perl
 
 use strict;
 use warnings;
 
 use base 'MoopsX::UsingMoose';
-
 use Acme::Resume::Moose();
 use Time::Moment;
 use syntax();
@@ -38,11 +37,26 @@ __END__
 
 =head1 NAME
 
-Acme::Resume - Write a humuan-readable rÃ©sumÃ© in Perl
+Acme::Resume - Write a human-readable resume in Perl
+
+
+
+=begin HTML
+
+<p><img src="https://img.shields.io/badge/perl-5.14+-brightgreen.svg" alt="Requires Perl 5.14+" /> <a href="https://travis-ci.org/Csson/p5-Acme-Resume"><img src="https://api.travis-ci.org/Csson/p5-Acme-Resume.svg?branch=master" alt="Travis status" /></a> <img src="https://img.shields.io/badge/coverage-86.4%-orange.svg" alt="coverage 86.4%" /></p>
+
+=end HTML
+
+
+=begin markdown
+
+![Requires Perl 5.14+](https://img.shields.io/badge/perl-5.14+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Acme-Resume.svg?branch=master)](https://travis-ci.org/Csson/p5-Acme-Resume) ![coverage 86.4%](https://img.shields.io/badge/coverage-86.4%-orange.svg)
+
+=end markdown
 
 =head1 VERSION
 
-Version 0.0101, released 2015-04-04.
+Version 0.0102, released 2016-01-27.
 
 =head1 SYNOPSIS
 
@@ -133,7 +147,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
